==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialogshownotes.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGSHOWNOTES
#define INCLUDED_DIALOGSHOWNOTES

#include <gtk/gtk.h>
#include "libraries.h"
#include "configuration.h"


class ShowNotesDialog
{
public:
  ShowNotesDialog (Configuration * configuration);
  virtual ~ShowNotesDialog ();
  virtual int run();
protected:
  GtkWidget *shownotesdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *table1;
  GtkWidget *radiobuttoncategory;
  GtkWidget *combobox1;
  GtkWidget *radiobuttoncurrentverse;
  GtkWidget *radiobuttontoday;
  GtkWidget *radiobuttonall;
  GtkWidget *radiobuttondate;
  GtkWidget *hbox2;
  GtkWidget *fromdatebutton;
  GtkWidget *alignment1;
  GtkWidget *hbox4;
  GtkWidget *image1;
  GtkWidget *label1;
  GtkWidget *labeldatefrom;
  GtkWidget *hbox3;
  GtkWidget *todatebutton;
  GtkWidget *alignment2;
  GtkWidget *hbox5;
  GtkWidget *image2;
  GtkWidget *label2;
  GtkWidget *labeltodate;
  GtkWidget *checkbuttoncurrentproject;
  GtkWidget *checkbutton_showproject;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
private:
  static void on_radiobutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
  static void on_fromdatebutton_clicked (GtkButton *button, gpointer user_data);
  static void on_todatebutton_clicked (GtkButton *button, gpointer user_data);
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_from_date ();
  virtual void on_to_date ();
  virtual void on_ok ();
  virtual void set_gui();
  virtual ShowNotesSelector get_state ();
  Configuration * myconfiguration;
  guint32 from_day;
  guint32 to_day;
};


#endif

==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/dialogshownotes.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGSHOWNOTES
#define INCLUDED_DIALOGSHOWNOTES


#include <gtk/gtk.h>
#include "libraries.h"
#include "notes_utils.h"


class ShowNotesDialog
{
public:
  ShowNotesDialog (int dummy);
  ~ShowNotesDialog ();
  int run();
protected:
  GtkWidget *shownotesdialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *table1;
  GtkWidget *radiobuttoncategory;
  GtkWidget *combobox1;
  GtkWidget *radiobuttoncurrentverse;
  GtkWidget *radiobuttontoday;
  GtkWidget *radiobuttonall;
  GtkWidget *radiobuttondate;
  GtkWidget *hbox2;
  GtkWidget *fromdatebutton;
  GtkWidget *alignment1;
  GtkWidget *hbox4;
  GtkWidget *image1;
  GtkWidget *label1;
  GtkWidget *labeldatefrom;
  GtkWidget *hbox3;
  GtkWidget *todatebutton;
  GtkWidget *alignment2;
  GtkWidget *hbox5;
  GtkWidget *image2;
  GtkWidget *label2;
  GtkWidget *labeltodate;
  GtkWidget *checkbuttoncurrentproject;
  GtkWidget *checkbutton_showproject;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
private:
  static void on_radiobutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
  static void on_fromdatebutton_clicked (GtkButton *button, gpointer user_data);
  static void on_todatebutton_clicked (GtkButton *button, gpointer user_data);
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  void on_from_date ();
  void on_to_date ();
  void on_ok ();
  void set_gui();
  ShowNotesSelector get_state ();
  guint32 from_day;
  guint32 to_day;
};


#endif
